const cenode = require('./cenode');
const model = require('../models/cenodeModel');
const nodeManager = require('../modules/nodeManager');
var node = new cenode.CENode(cenode.MODELS.CORE, model.ceModel.model);

// maps event types to field names for parsing
var eventMap = {
  presence: "body",
  temperature: "centidegreeCelsius",
  motion: "avgIntensity"
};

module.exports = {
  parseSubscriptionEvent: function (event) {
    var data = event.data;
    var cookieName = nodeManager.nodes[event.nodeUid].label;
    var telemetryType = event.type;
    var cookieTelemetry = data[eventMap[telemetryType]];
    var sentence;

    // special case handling for presence detection, since we can't deal with this in the model.
    if (telemetryType == "presence" && cookieTelemetry == "Present") {
      sentence = 'The cookie \'' + cookieName + '\' is in the location \'home\'';
    } else if (telemetryType == "presence" && cookieTelemetry == "Absent") {
      sentence = 'The cookie \'' + cookieName + '\' is in the location \'not home\'';
    } else {
      sentence = 'The cookie \'' + cookieName + '\' has \'' + cookieTelemetry + '\' as ' + telemetryType;
    }

    return this.addSentence(sentence);
  },

  addSentence: function (sentence) {
    return node.add_sentence(sentence);
  },

  getConcepts: function () {
    return node.get_concepts();
  },

  getInstances: function (type, recurse) {
    return node.get_instances(type, recurse);
  },

  setAgentName: function (agentName) {
    return node.agent.set_name(agentName);
  },

  getAgentName: function () {
    return node.agent.get_name();
  },

  reset: function () {
    node.reset_all();
    node = new cenode.CENode(cenode.MODELS.CORE, model.ceModel.model);
  }
};